package com.roo.service;

import com.roo.commons.tools.page.PageData;
import com.roo.commons.tools.validator.ValidatorUtils;
import com.roo.commons.tools.validator.group.AddGroup;
import com.roo.commons.tools.validator.group.DefaultGroup;
import com.roo.dto.*;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.HashMap;
import java.util.Map;

@RunWith(SpringRunner.class)
@SpringBootTest
public class AllServiceTest {

    private static Logger logger = LoggerFactory.getLogger(AllServiceTest.class);

    @Autowired
    private AppRevisionService appRevisionService;

    @Autowired
    private BlockChainService blockChainService;

    @Autowired
    private ChainNodesService chainNodesService;

    @Autowired
    private DappsService dappsService;

    @Autowired
    private MarketService marketService;

    @Autowired
    private OtcService otcService;

    @Autowired
    private TokenService tokenService;

    @Test
    public void testAppRevisionPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("platform", "android");
        params.put("version", "0.2.0");
        PageData<AppRevisionDTO> page = appRevisionService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testBlockChainPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("isEnabled", true);
        params.put("code", "BSC");
        PageData<BlockChainDTO> page = blockChainService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testChainNodesPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("chainCode", "BSC");
        params.put("network", "TEST");
        params.put("isEnabled", true);
        PageData<ChainNodesDTO> page = chainNodesService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testDappsPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("name", "paraswap");
        params.put("hots", true);
        params.put("chain", "ethereum");
        params.put("display", "show");
        PageData<DappsDTO> page = dappsService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testMarketPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("symbol", "BTC_USDT");
        params.put("baseAsset", "BTC");
        params.put("quoteAsset", "USDT");
        PageData<MarketDTO> page = marketService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testOtcPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("isEnabled", true);
        params.put("symbol", "cny");
        PageData<OtcDTO> page = otcService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testTokenPageParams() {
        Map<String, Object> params = new HashMap<>();
        params.put("page", "1");
        params.put("limit", "10");
        params.put("blockChainCode", "ETH");
        params.put("symbol", "USDT");
        params.put("contractId", "0xdac17f958d2ee523a2206206994597c13d831ec7");
        params.put("isRecommend", true);
        params.put("isSearch", true);
        params.put("isScan", true);
        PageData<TokenDTO> page = tokenService.page(params);
        logger.info("total:{}", page.getTotal());
    }

    @Test
    public void testValidate(){
        DappsDTO dto = new DappsDTO();
        dto.setChain("BSC");
        dto.setDiscription("AAA");
        dto.setDisplay("show");
        dto.setHots(1);
        dto.setType("DEX");
        dto.setName("qq");
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);
    }
}
