/**
 * Copyright (c) 2020  All rights reserved.
 * <p>
 *
 * <p>
 *
 */
package com.roo.controller;

import com.roo.commons.tools.constant.Constant;
import com.roo.commons.tools.page.PageData;
import com.roo.commons.tools.utils.Result;
import com.roo.commons.log.annotation.LogOperation;
import com.roo.entity.FlowModelEntity;
import com.roo.service.FlowModelService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import springfox.documentation.annotations.ApiIgnore;

import java.util.Map;

/**
 * 模型管理
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestController
@RequestMapping("model")
@AllArgsConstructor
@Api(tags="模型管理")
public class FlowModelController {
    private final FlowModelService flowModelService;

    @GetMapping("page")
    @ApiOperation("分页")
    @ApiImplicitParams({
        @ApiImplicitParam(name = Constant.PAGE, value = "当前页码，从1开始", paramType = "query", required = true, dataType="int") ,
        @ApiImplicitParam(name = Constant.LIMIT, value = "每页显示记录数", paramType = "query",required = true, dataType="int") ,
        @ApiImplicitParam(name = "key", value = "key", paramType = "query", dataType="String"),
        @ApiImplicitParam(name = "name", value = "name", paramType = "query", dataType="String")
    })
    @PreAuthorize("hasAuthority('sys:model:all')")
    public Result<PageData<FlowModelEntity>> page(@ApiIgnore @RequestParam Map<String, Object> params){
        PageData<FlowModelEntity> page = flowModelService.page(params);

        return new Result<PageData<FlowModelEntity>>().ok(page);
    }

    @PostMapping("deploy/{id}")
    @ApiOperation("部署")
    @LogOperation("部署")
    @PreAuthorize("hasAuthority('sys:model:all')")
    public Result deploy(@PathVariable("id") String id) {
        flowModelService.deploymentByModelId(id);
        return new Result();
    }
}
