/**
 * Copyright (c) 2020  All rights reserved.
 * <p>
 *
 * <p>
 *
 */
package com.roo.demo.controller;

import com.roo.commons.tools.utils.Result;
import com.roo.commons.tools.validator.ValidatorUtils;
import com.roo.commons.tools.validator.group.AddGroup;
import com.roo.commons.tools.validator.group.DefaultGroup;
import com.roo.service.FlowRunningService;
import com.roo.commons.security.user.SecurityUser;
import com.roo.demo.service.CorrectionService;
import com.roo.dto.CorrectionDTO;
import com.roo.dto.ProcessInstanceDTO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * 转正申请
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestController
@RequestMapping("demo/correction")
@AllArgsConstructor
@Api(tags="转正申请")
public class CorrectionController {
    private final CorrectionService correctionService;
    private final FlowRunningService flowRunningService;

    @PostMapping("start")
    @ApiOperation("启动流程")
    @PreAuthorize("hasAuthority('sys:flow:all')")
    public Result startProcess(@RequestBody CorrectionDTO dto){
        //效验数据
        ValidatorUtils.validateEntity(dto, AddGroup.class, DefaultGroup.class);

        //保存表单
        correctionService.save(dto);

        Map<String, Object> variables = new HashMap<>();
        variables.put("USERNAME", SecurityUser.getUserId().toString());
        ProcessInstanceDTO process = flowRunningService.startProcessInstanceById
                (dto.getProcessDefinitionId(), dto.getId() + "", variables);

        dto.setInstanceId(process.getProcessInstanceId());

        //更新流程实例ID
        correctionService.updateInstanceId(process.getProcessInstanceId(), dto.getId());

        return new Result();
    }

    @GetMapping("{id}")
    @ApiOperation("表单信息")
    @PreAuthorize("hasAuthority('sys:flow:all')")
    public Result<CorrectionDTO> info(@PathVariable("id") Long id){
        CorrectionDTO correction = correctionService.get(id);

        return new Result<CorrectionDTO>().ok(correction);
    }

}
